@@ -1,4 +1,6 @@
 import boto3
+import botocore
+import time
 from datetime import datetime
 import pyarrow as pa
 import pyarrow.parquet as pq
@@ -6,6 +8,8 @@ from s3transfer import S3UploadFailedError
 from s3fs import S3FileSystem
 from airflow_commons.logger import LOGGER
 
+DEFAULT_RETRY_COUNT = 3
+
 
 def get_param(key, region_name: str = "eu-west-1"):
     ssm = boto3.client("ssm", region_name=region_name)
@@ -28,7 +32,7 @@ def upload_file_to_s3_bucket(path_to_file: str, bucket_name: str, file_name: str
         s3_client.upload_file(path_to_file, bucket_name, file_name)
     except S3UploadFailedError as e:
         LOGGER("Upload to " + bucket_name + " failed")
-        raise Exception(e)
+        raise e
     upload_end = datetime.now()
     LOGGER(
         (
@@ -40,7 +44,12 @@ def upload_file_to_s3_bucket(path_to_file: str, bucket_name: str, file_name: str
 
 
 def write_into_s3_file(
-    bucket_name: str, file_name: str, data: str, key: str = None, secret: str = None
+    bucket_name: str,
+    file_name: str,
+    data: str,
+    key: str = None,
+    secret: str = None,
+    retry_count: int = DEFAULT_RETRY_COUNT,
 ):
     """
     Writes the given string data into the specified file in the specified bucket. If file does not exists create one, if
@@ -51,6 +60,7 @@ def write_into_s3_file(
     :param data: A string contains the content of the file
     :param key: AWS access key id, default is None
     :param secret: AWS secret access key, default is None
+    :param retry_count: retry count for S3 upload equals to three on default
     """
     if key is not None and secret is not None:
         s3 = S3FileSystem(key=key, secret=secret)
@@ -59,8 +69,17 @@ def write_into_s3_file(
 
     LOGGER("Writing to " + bucket_name + "/" + file_name + " started")
     writing_start = datetime.now()
-    with s3.open(bucket_name + "/" + file_name, "w") as f:
-        f.write(data)
+    total_upload_tries = 0
+    while total_upload_tries <= retry_count:
+        with s3.open(bucket_name + "/" + file_name, "w") as f:
+            try:
+                f.write(data)
+                break
+            except botocore.exceptions.NoCredentialsError as e:
+                total_upload_tries = total_upload_tries + 1
+                if total_upload_tries == retry_count:
+                    raise e
+                time.sleep(1)
     writing_end = datetime.now()
     LOGGER(
         (
